***BA Marr Fert
*Fert data creation
*v7
*Caroline Krafft, Elizabeth Kula
*Original: 11/19/17
*Updated: 7/18/20


***************************
*Annualized childbearing 
***************************

use "Data/Eat/JLMPS 2016 Jordanian women.dta", clear

*Keep married with marriages 1974 or later
keep if evermarried==1
keep if yr1stmarr>=1974 & yr1stmarr<.

*Keep needed variables
keep age sex indid yrbirth* sxchild* expan_indiv brthyr yr1stmarr sex ///
q3001 q2121 q3006_a q2123 q2125 q2126 q2128 q3011 q3018 q3032 q3043 ///
mteducst fteducst mtempst ftempst q213* q214* educ_3cat q2502 qwealth gov urban ///
visit_y yrschl nationality_cl marital

rename yrbirth* yrbirth_* 
rename sxchild* sxchild_*


gen yrbirth_0=yr1stmarr

*Finding those married and first birth in same year
count if yrbirth_0 == yrbirth_1
*208
count
*9401
/* 208/9401 =  2.21% */

reshape long yrbirth_@ sxchild_@, i(indid) j(bord)

sort indid bord

la var bord "Birth number" 
la val bord

*Drop if didn't have birth
keep if yrbirth_!=.

*Drop strays not in interval
keep if yrbirth_>=1974

*Drop if don't know year
drop if yrbirth_==9998

*Have a male child already
gen ch_male=0 if sxchild_==2
replace ch_male=1 if sxchild_==1

gen n_male=0 
bysort indid: replace n_male=sum(ch_male)
 
*Have male
gen have_male=(n_male!=0)

*Dropping multiple in same year
duplicates report indid yrbirth_
duplicates drop indid yrbirth_, force

sort indid yrbirth_ bord


*Year interval as a survival model
gen interval=.
replace interval=yrbirth_[_n+1]-yrbirth_[_n] if indid[_n]==indid[_n+1]

gen has_next=0
replace has_next=1 if interval!=.
replace interval=(2017-yrbirth_) if interval==.

sum interval

table yrbirth_ if has_next==1 [aw=expan], c(mean interval)

*Expand for each year in the interval

expand interval

bysort bord indid: gen int_length=_n

sort indid bord int_length

tabu int_length

*Failure
gen next_born=0
bysort indid bord: replace next_born=1 if has_next==1 & int_length==_N

*Generate a variable for the birth year
bysort indid bord: gen interval_year=floor((yrbirth_+_n))

tabu interval_year

*Generating age in year

gen age_inyr=interval_year-brthyr+1

tabu age_inyr
*Small n improbable
drop if age_inyr<0

*Age groups for age in year

gen yr_agroup=.
replace yr_agroup=1 if age_inyr>=0 & age_inyr<=19
replace yr_agroup=2 if age_inyr>=20 & age_inyr<=24
replace yr_agroup=3 if age_inyr>=25 & age_inyr<=29
replace yr_agroup=4 if age_inyr>=30 & age_inyr<=34
replace yr_agroup=5 if age_inyr>=35 & age_inyr<=39
replace yr_agroup=6 if age_inyr>=40 & age_inyr<=44
replace yr_agroup=7 if age_inyr>=45 & age_inyr<=50

la def Lyr_agroup 1 "<20" 2 "20-24" 3 "25-29" 4 "30-34" 5 "35-39" ///
6 "40-44" 7 "45-49"

la val yr_agroup Lyr_agroup

tabu yr_agroup, miss
tabu yr_agroup, gen(yra)

*Birth cohort
recode brthyr (1950/1964=2) (1965/1969=3) (1970/1974=4) (1975/1979=5) ///
(1980/1984=6) (1985/1989=7) (1990/2001=8), gen(by_coh)

tabu by_coh, miss

*Year

gen year=interval_year
replace year=. if year>2017

*Age in year
keep if age_inyr>=15 & age_inyr<=49

*We can recode year into cohorts
keep if year>=2000 & year<=2016

recode year (2000/2004=1) ///
(2005/2009=2) (2010/2016=3) (.=.) (9998=.), gen(tyr)

label var tyr "Years"
label define tyrlab 1 "2000-2004" 2 "2005-2009" 3 "2010-2016", modify
label values tyr tyrlab
tab year tyr

tabu tyr, miss

*Birth id
label val bord 
tabu bord

tostring bord, gen(s_bord)
replace s_bord="0"+s_bord if bord<10

gen bid=indid+s_bord

*duplicates report bid int_length

*Aggregating higher intervals

tabu int_length next_born [aw=expan], row
tabu int_length next_born, row
*Past 6 years few generate births

tabu bord [aw=expan] if int_length==1
*15% past four births

gen c_bord=bord
replace c_bord=4 if c_bord>4 & c_bord<.

gen c_int_length=int_length
replace c_int_length=6 if c_int_length>6 & c_int_length<.

label var c_bord "Parity"
label var c_int_length "Years since last event"


*Keep for modeling
keep indid expan_indiv gov urban educ_3cat c_bord ///
c_int_length next_born have_male year yr_agroup

rename expan_indiv sample_wt
rename urban urban_rural

save "Data/JLMPS 2016 annual fert.dta", replace
