***BA Marr Fert
*Fert desc 
*v15
*Caroline Krafft, Libby Kula
*Original: 12/4/17
*Updated: 7/27/20

clear
set scheme s1mono

***************************
*Data setup
***************************

use "Data/Eat/JLMPS 2016 Jordanian women.dta", clear
append using "Data/Eat/JLMPS 2010 Jordanian women.dta"

*Only Jordanian women 15-49
fre nationality_cl
fre sex
fre age
fre round

/*Stat: sample size, JLMPS*/
tab round, mi
tab round evermarried, mi

sort indid
*Random number generator for imputed months
set seed 81718868



*CMC dates - mother's birthdate accounting for month of birth
*Creating a random month if missing
gen random=runiform()
gen brthmth2=ceil(random*12) if brthmth==. 
replace brthmth=brthmth2 if brthmth==.

*CMC birthdate
gen cmcbrthyr=(brthyr-1900)*12+brthmth
*tabu cmcbrthyr

*CMC date for survey
gen cmcsurvey=(visit_y-1900)*12+visit_m

tabu cmcsurvey

**CHILD DATE OF BIRTH
*remove those with missing yob 
recode yrbirth* (9998=.)

rename yrbirth* yrbirth_* 
rename mnthbirth* mnthbirth_*

**Fixed to account for month of birth - replace missing month data
foreach num of numlist 1/15 {

gen random_`num'=runiform()
replace mnthbirth_`num'=visit_m if mnthbirth_`num'==98 & yrbirth_`num'==visit_y
replace mnthbirth_`num'=ceil(random_`num')*12 if mnthbirth_`num'==98

gen cmcyrbirth_`num'=(yrbirth_`num'-1900)*12+mnthbirth_`num'
tabu cmcyrbirth_`num'
}

***************************
*Descriptives
***************************

*JORDANIANS 2016
tfr2 [pw=expan_indiv] if round==2016, bvar(cmcyrbirth_*) len(3) date(cmcsurvey) wb(cmcbrthyr) ageg(5) saverates("Data/Eat/JordASFRs2016.dta", replace)

*2016 by chars
tfr2 [pw=expan_indiv] if round==2016 & educ_3cat==1, bvar(cmcyrbirth_*) len(3) date(cmcsurvey) wb(cmcbrthyr) ageg(5) saverates("Data/Eat/JordASFRs2016_less.dta", replace)
tfr2 [pw=expan_indiv] if round==2016 & educ_3cat==2, bvar(cmcyrbirth_*) len(3) date(cmcsurvey) wb(cmcbrthyr) ageg(5) saverates("Data/Eat/JordASFRs2016_sec.dta", replace)
tfr2 [pw=expan_indiv] if round==2016 & educ_3cat==3, bvar(cmcyrbirth_*) len(3) date(cmcsurvey) wb(cmcbrthyr) ageg(5) saverates("Data/Eat/JordASFRs2016_high.dta", replace)

*single year fertility trends
tfr2 [pw=expan_indiv] if round==2016, bvar(cmcyrbirth_*) len(10) date(cmcsurvey) wb(cmcbrthyr) ageg(5) trend(1) se savetrend("Data/Eat/TFRtrend_2016.dta", replace) 


**********
*2010
**********


*JORDANIANS 2010
tfr2 [pw=expan_indiv] if round==2010, bvar(cmcyrbirth_*) len(3) date(cmcsurvey) wb(cmcbrthyr) ageg(5) saverates("Data/Eat/JordASFRs2010.dta", replace)

*2010 by chars
tfr2 [pw=expan_indiv] if round==2010 & educ_3cat==1, bvar(cmcyrbirth_*) len(3) date(cmcsurvey) wb(cmcbrthyr) ageg(5) saverates("Data/Eat/JordASFRs2010_less.dta", replace)
tfr2 [pw=expan_indiv] if round==2010 & educ_3cat==2, bvar(cmcyrbirth_*) len(3) date(cmcsurvey) wb(cmcbrthyr) ageg(5) saverates("Data/Eat/JordASFRs2010_sec.dta", replace)
tfr2 [pw=expan_indiv] if round==2010 & educ_3cat==3, bvar(cmcyrbirth_*) len(3) date(cmcsurvey) wb(cmcbrthyr) ageg(5) saverates("Data/Eat/JordASFRs2010_high.dta", replace)

*single year fertility trends
tfr2 [pw=expan_indiv] if round==2010, bvar(cmcyrbirth_*) len(10) date(cmcsurvey) wb(cmcbrthyr) ageg(5) trend(1) se savetrend("Data/Eat/TFRtrend_2010.dta", replace) 



****Data for survival by parity

keep if round==2016

gen cmcintdate=cmcsurvey
gen cmcmarr=(yr1stmarr-1900)*12+q2105a if q2105a!=98

keep expan_indiv cmc* indid round
rename expan_indiv sample_wt

save "Data/Eat/JLMPS 2016 cmcs.dta", replace

