***BA Marr Fert
*Fert Models: DHS & JLMPS
*v14

*Caroline Krafft, Libby Kula
*Original: 2017/11/19
*Updated: 2020/07/31

*set matsize 1000
*EK- won't allow matsize >800
set matsize 800

estimates clear

set scheme s1mono

use "Data/JLMPS 2016 annual fert.dta", clear

gen round=2016
append using "Data/DHS 2017 annual fert.dta"
replace round=2017 if round==.

*Checks
tabu year round
bysort round: sum

la def Lyear 2000 "2000" 2001 "2001" 2002 "2002" 2003 "2003" ///
2004 "2004" 2005 "2005" 2006 "2006" 2007 "2007" 2008 "2008" ///
2009 "2009" 2010 "2010" 2011 "2011" 2012 "2012" 2013 "2013" ///
2014 "2014" 2015 "2015" 2016 "2016"

la val year Lyear

label def Lc_bord 0 "Marr." 1 "1st" 2 "2nd" 3 "3rd" 4 "4th+", modify
label values c_bord Lc_bord

*Periods based on tests, below
recode year (2000/2011=1) (2012/2013=2) (2014/2016=3), gen(tyr)


*********************************
*Next birth is outcome
*********************************

*************************************************************
***Probability of childbearing per year, controlling for age 
*************************************************************
*Equivalent to ASFR

foreach num of numlist 2016/2017 {

cloglog next_born b2008.year b3.yr_agroup [pw=sample_wt] if round==`num',  eform cluster(indid) 

estimates store est0_`num'

test 2000.year 2001.year 2002.year 2003.year 2004.year 2005.year 2006.year 2007.year 2009.year 2010.year 2011.year
test 2000.year=2001.year=2002.year=2003.year=2004.year=2005.year=2006.year=2007.year=2009.year=2010.year=2011.year

*Driven by 2011
test 2000.year 2002.year 2003.year 2004.year 2005.year 2006.year 2007.year 2009.year 2010.year 2011.year
test 2000.year=2002.year=2003.year=2004.year=2005.year=2006.year=2007.year=2009.year=2010.year=2011.year

test 2012.year 2013.year
test 2012.year=2013.year

test 2014.year 2015.year 2016.year
test 2014.year=2015.year=2016.year

}


*Pooling to check for sig. diff. 
cloglog next_born b2017.round##b2008.year b3.yr_agroup [pw=sample_wt],  eform cluster(indid) 

*************************************************************
***Time trends--grouped years
*************************************************************

foreach num of numlist 2016/2017 {

cloglog next_born b1.tyr ///
b3.yr_agroup [pw=sample_wt] if round==`num',  eform cluster(indid) 

estimates store est1_`num'

test 2.tyr 3.tyr
test 2.tyr=3.tyr
}



*************************************************************
***Time trends and age in year interactions
*************************************************************


foreach num of numlist 2016/2017 {

cloglog next_born b1.tyr##b3.yr_agroup [pw=sample_wt] if round==`num',  eform cluster(indid) 

estimates store est2_`num'

test 2.tyr 3.tyr
test 2.tyr=3.tyr
}

*************************************************************
***Time trends, age in year, education interacted with period
*************************************************************


foreach num of numlist 2016/2017 {

cloglog next_born b1.tyr##b1.educ_3cat b3.yr_agroup [pw=sample_wt] if round==`num',  eform cluster(indid) 

estimates store est3_`num'

testparm  2.educ_3cat#tyr 2.educ_3cat
testparm  3.educ_3cat#tyr 3.educ_3cat

test 2.tyr#2.educ_3cat 3.tyr#2.educ_3cat 2.tyr#3.educ_3cat 3.tyr#3.educ_3cat

test 3.tyr#3.educ_3cat+3.educ_3cat=0

test 3.tyr#2.educ_3cat+2.educ_3cat=0

test 3.tyr#3.educ_3cat+3.educ_3cat=3.tyr#2.educ_3cat+2.educ_3cat
 
}



*************************************************************
***Time trends, age in year, education interacted with period
*************************************************************


foreach num of numlist 2016/2017 {

cloglog next_born b1.tyr##b1.educ_3cat##b3.yr_agroup [pw=sample_wt] if round==`num',  eform cluster(indid) 

estimates store est4_`num'

}


*************************************************************
***Time trends, age in year, education, parity, and interval, parity interacted with time. 
*************************************************************


foreach num of numlist 2016/2017 {

cloglog next_born b1.tyr b1.educ_3cat b3.yr_agroup b0.c_bord##b1.c_int_length ///
b0.c_bord#b1.tyr [pw=sample_wt] if round==`num',  eform cluster(indid) 

estimates store est5_`num'

}




lab def year_range 1 "2000-2011" 2 "2012-2013" 3 "2014-2016"
lab val tyr year_range 

la def Lc_int_length 1 "One year" 2 "Two years" 3 "Three years" 4 "Four years" ///
5 "Five years" 6 "Six or more years"
la val c_int_length Lc_int_length

/* Table A-2. Fertility models */
esttab est0_* est1_* est2_* est3_* est4_* est5_* ///
  using "Graphs and Tables/FertModels_both.csv", cells(b(star fmt(%9.3f)) se(par))   ///     
 stats(N N_s, fmt(%9.0g %9.0g) labels("N obs." "N individuals")) label  ///
 nobase noomit ///
 refcat(2000.year "Year (2008 omit.)" 2.tyr "Years (2000-2011 omit.)" ///
 1.yr_agroup "Age group (25-29 omit.)" ///
 2.tyr#1.yr_agroup "Years and age group int." 2.educ_3cat ///
 "Ed. (less than sec. omit.)" 2.tyr#2.educ_3cat "Years and ed. int." ///
 2.educ_3cat#1.yr_agroup "Ed. and age group int." ///
 2.tyr#2.educ_3cat#1.yr_agroup "Years and ed. and age group int." ///
 1.c_bord "Parity (Marr. omit.)" 2.c_int_length "Time since last birth or marr. (1 yr. omit.)" ///
 1.c_bord#2.tyr "Parity and time int." ///
 , nolabel) indicate( "Parity and interval int." =  *c_bord#*c_int_length*) ///
	legend  mlabel("JLMPS 2016" "JPFHS 2017/18" ///
	"JLMPS 2016" "JPFHS 2017/18"  ///
	"JLMPS 2016" "JPFHS 2017/18"  ///
	"JLMPS 2016" "JPFHS 2017/18"  ///
	"JLMPS 2016" "JPFHS 2017/18"  ///
	"JLMPS 2016" "JPFHS 2017/18" , ) ///
	eform replace
