***BA Marr Fert
*Data creation
*v9
*Caroline Krafft, Elizabeth Kula
*Original: 11/19/17
*Updated: 7/22/2020


***************************
*Annualized marital status 
***************************

use "Data/JLMPS 2016 xs v1.1 pt 1.dta", clear

*Jordanians only
keep if nationality_cl==1

*Adults only, ages 15-49
keep if age>=15 & age<=49

*Women only
keep if sex==2

*Slight cleaning of birth year to align with age for expansion
tabu brthyr, miss
replace brthyr=visit_y-age if brthyr==.
replace brthyr=visit_y-age if brthyr+age>visit_y & brthyr!=. & age!=.
replace brthyr=visit_y-age if brthyr+age<visit_y-1 & brthyr!=. & age!=. & visit_y!=.
replace brthyr=2016-age if brthyr+age<visit_y-1 & brthyr!=. & age!=. & visit_y==.

*Valid in individual data only
keep if expan_indiv!=.

*Ever married
gen evermarried=0 if marital==1
replace evermarried=1 if marital>=2 & marital<=5

tabu evermarried marital, miss

*Generate age at marriage, current age if not married
gen agemarr=.
replace agemarr=age if evermarried==0
replace agemarr=age1stmarr if evermarried==1
*Slight cleaning
replace agemarr=age if agemarr>age & agemarr!=. & age!=.

tabu agemarr evermarried, miss

*Final education
tab educ1d

recode educ1d (1/3=1)(4=2)(5/7=3), gen(educ_3cat)

tabu educ_3cat educ1d, miss

label define Leduc_3cat 1 "Less than Secondary" 2 "Secondary" 3 "Higher"

label val educ_3cat Leduc_3cat
label var educ_3cat "Education level (three categories)" 
 
 
save "Data/Eat/JLMPS 2016 Jordanian women.dta", replace


keep age agemarr evermarried sex brthyr indid expan_indiv ///
q3001 q2121 q3006_a q2123 q2125 q2126 q2128 q3011 q3018 q3032 q3043 ///
mteducst fteducst mtempst ftempst q213* q214* gov urban  ///
visit_y yrschl nationality_cl educ_3cat

*Expanding for marriage up to age 59

compress

*Expand to allow for TVCs
drop if agemarr==.
expand agemarr

bysort indid: gen spell_yr = _n
label variable spell_yr "spell year identifier, by subject"

tabu spell_yr, miss

*Calendar year
gen year=brthyr+spell_yr
tabu year, miss

*Married
bysort indid: gen marr = 1 if evermarried==1 & _n==_N
label variable marr "married at this age"

tab marr if sex==1

recode marr (.=0)

tabu marr evermarried, miss

***Creating a time variable

*We can recode year into cohorts
keep if year>=2000 & year<=2016

tabu spell_yr marr, miss

*Drop if below 15 or above 49
drop if spell_yr<15
drop if spell_yr>49

***Combining <18 & >32
replace spell_yr=18 if spell_yr<18
replace spell_yr=32 if spell_yr>32 & spell_yr!=.

*****************
*Covariates
*****************

*In schoool

*In basic  
gen inschool_1=.
*Never went
replace inschool_1=0 if q3001==1
*Before started
replace inschool_1=0 if q2121>year & q2121<9998
*After finished
replace inschool_1=0 if q3043<year & q3043<9998
*During school
replace inschool_1=1 if q2121<=year & q3043>=year & q3043!=9998 & q3043!=.
*Currently in school
replace inschool_1=1 if q2121<=year & q3001==3 & q3006_a==1
*Interruption
replace inschool_1=0 if q2123==1 & year>=q2125 & year<q2126
 
*In secondary  
gen inschool_2=.
*Never went
replace inschool_2=0 if q3001==1
replace inschool_2=0 if q3006_a==1
*Before started
replace inschool_2=0 if q2121>year & q2121<9998
replace inschool_2=0 if inschool_1==1
*After finished
replace inschool_2=0 if q3032<year & q3032<9998
*During school
replace inschool_2=1 if q2121<=year & q3032>=year & q3032!=9998 & q3032!=. & inschool_1!=1
*Currently in school
replace inschool_2=1 if q2121<=year & q3001==3 & q3006_a>=2 & q3006_a<=3 & inschool_1!=1
*Interruption
replace inschool_2=0 if q2123==1 & year>=q2125 & year<q2126
  
*In tertiary  
gen inschool_3=.
*Never went
replace inschool_3=0 if q3001==1
replace inschool_3=0 if q3006_a<4
*Before started
replace inschool_3=0 if q2121>year & q2121<9998
replace inschool_3=0 if inschool_1==1
replace inschool_3=0 if inschool_2==1
*After finished
replace inschool_3=0 if q2128<year & q2128<9998
*During school
replace inschool_3=1 if q2121<=year & q3018>=year & q3018!=9998 & q3018!=. & year<=q2128 & q2128!=. & inschool_1!=1 & inschool_2!=1
replace inschool_3=1 if q2121<=year & q3011>=year & q3011!=9998 & q3011!=. & year<=q2128 & q2128!=. & inschool_1!=1 & inschool_2!=1
*Currently in school
replace inschool_3=1 if q2121<=year & q3001==3 & q3006_a>=4 & q3006_a<. & inschool_1!=1 & inschool_2!=1
*Interruption
replace inschool_3=0 if q2123==1 & year>=q2125 & year<q2126

*In school
gen inschool=.
replace inschool=0 if inschool_1==0 | inschool_2==0 | inschool_3==0
replace inschool=1 if inschool_1==1 | inschool_2==1 | inschool_3==1
*If missing data 
replace inschool=1 if inschool==. & q2121<=year & q2128>=year & q2121!=. & q2128!=. & q2121!=9998 & q2128!=9998
replace inschool=0 if inschool==. & (q2121>year | q2128<year) & q2121!=. & q2128!=. & q2121!=9998 & q2128!=9998
replace inschool=1 if inschool==. & year>=brthyr+6 & year<=yrschl+brthyr+6
replace inschool=0 if inschool==. & (year<brthyr+6 | year>yrschl+brthyr+6)

tabu inschool, miss
tabu spell_yr inschool, miss 
 
la var inschool "In school"

keep marr spell_yr inschool indid ///
year expan_indiv ///
educ_3cat gov urban


rename expan_indiv sample_wt
rename urban urban_rural
 
save "Data/JLMPS 2016 annual marr.dta", replace
