***BA Marr Fert
*Marr Models: DHS & JLMPS
*v14
*Caroline Krafft, Libby Kula
*Original: 2017/11/19
*Updated: 2020/07/30

*set matsize 1000
*EK- won't allow matsize >800
set matsize 800

estimates clear

set scheme s1mono

use "Data/JLMPS 2016 annual marr.dta", clear

gen round=2016
append using "Data/DHS 2017 annual marr.dta"
replace round=2017 if round==.


*Checks
tabu year round
bysort round: sum

la def Lyear 2000 "2000" 2001 "2001" 2002 "2002" 2003 "2003" ///
2004 "2004" 2005 "2005" 2006 "2006" 2007 "2007" 2008 "2008" ///
2009 "2009" 2010 "2010" 2011 "2011" 2012 "2012" 2013 "2013" ///
2014 "2014" 2015 "2015" 2016 "2016"

la val year Lyear

*Periods based on tests, below
recode year (2000/2007=1) (2008/2009=2) (2010/2011=3) (2012/2016=4), gen(tyr)


*********************************
*Age at marriage
*********************************

*************************************************************
***Time trends--single year
*************************************************************

foreach num of numlist 2016/2017 {
cloglog marr b2007.year if round==`num' [pw=sample_wt],  eform cluster(indid) 

estimates store mest1_`num'
}

*Controlling for age
foreach num of numlist 2016/2017 {
cloglog marr b18.spell_yr b2007.year if round==`num' [pw=sample_wt],  eform cluster(indid) 

estimates store mest2_`num'


test 2000.year 2001.year 2002.year 2003.year 2004.year 2005.year 2006.year
test 2000.year=2001.year=2002.year=2003.year=2004.year=2005.year=2006.year

*Driven by 2011
test 2008.year 2009.year
test 2008.year=2009.year

test 2010.year 2011.year
test 2010.year=2011.year

test 2012.year 2013.year 2014.year 2015.year 2016.year
test 2012.year=2013.year=2014.year=2015.year=2016.year

}


*************************************************************
***Time trends--grouped
*************************************************************


*Controlling for age
foreach num of numlist 2016/2017 {
cloglog marr b18.spell_yr b1.tyr if round==`num' [pw=sample_wt],  eform cluster(indid) 

estimates store mest3_`num'


test 2.tyr 3.tyr 4.tyr
test 2.tyr=3.tyr=4.tyr

test 2.tyr=3.tyr
test 2.tyr=4.tyr
test 3.tyr=4.tyr
}


*Interacting age, pile of noise
foreach num of numlist 2016/2017 {
cloglog marr b1.tyr##b18.spell_yr if round==`num' [pw=sample_wt],  eform cluster(indid) 

estimates store mest4_`num'


}



*Education
foreach num of numlist 2016/2017 {
cloglog marr b18.spell_yr b1.tyr b1.educ_3cat i.inschool if round==`num' [pw=sample_wt],  eform cluster(indid) 

*estimates store mest5_`num'


}



*Education interacted
foreach num of numlist 2016/2017 {
cloglog marr b18.spell_yr b1.tyr##b1.educ_3cat i.inschool if round==`num' [pw=sample_wt],  eform cluster(indid) 

estimates store mest6_`num'


}


lab def year_range 1 "2000-2007" 2 "2008-2009" 3 "2010-2011" 4 "2012-2016"
lab val tyr year_range 

la def Lspell_yr 18 "18 or less" 19 "19" 20 "20" 21 "21" 22 "22" 23 "23" 24 "24" ///
25 "25" 26 "26" 27 "27" 28 "28" 29 "29" 30 "30" 31 "31" 32 "32+"
la val spell_yr Lspell_yr

/* Table A.3. Marr models */
esttab mest1_* mest2_* mest3_* mest4_* /* mest5_* */ mest6_* ///
  using "Graphs and Tables/MarrModels_both.csv", cells(b(star fmt(%9.3f)) ///
  se(par))   ///     
 stats(N N_s, fmt(%9.0g %9.0g) labels("N obs." "N individuals")) label  ///
 nobase noomit ///
 refcat(19.spell_yr "Age in yr. (18 or less omit.)" 2.tyr#19.spell_yr ///
 "Age and years int." 2000.year "Year (2007 omit.)" ///
 2.tyr "Years (2000-2007 omit.)" 2.educ_3cat ///
 "Ed. (less than sec. omit.)" 2.tyr#2.educ_3cat "Years and ed. int." ///
 , nolabel) ///
	 coeflabel( 2001.year "2001" 2002.year "2002" 2003.year "2003" ///
	 2004.year "2004" 2005.year "2005" 2006.year "2006" 2007.year "2007" ///
	 2008.year "2008" 2009.year "2009" 2010.year "2010" 2011.year "2011" ///
	 2012.year "2012" 2013.year "2013" 2014.year "2014" 2015.year "2015" ///
	 1.inschool "In school" ) ///
	legend  mlabel("JLMPS 2016" "JPFHS 2017/18" ///
	"JLMPS 2016" "JPFHS 2017/18"  ///
	"JLMPS 2016" "JPFHS 2017/18"  ///
	"JLMPS 2016" "JPFHS 2017/18"  ///
	"JLMPS 2016" "JPFHS 2017/18"  ///
	"JLMPS 2016" "JPFHS 2017/18" , ) ///
	eform replace
