***DHS  
*Bongaarts decomposition of proximate determinants
*v15
*Libby Kula, Caroline Krafft
*Original: 2021.01.08
*Updated: 2021.04.07

clear
set scheme s1mono

******************
* Marriage index
*******************

** ASFRs
use "Data/Eat/DHSJordASFRs201718.dta", clear
append using "Data/Eat/DHSJordASFRs2012.dta"
append using "Data/Eat/DHSJordASFRs2009.dta"
append using "Data/Eat/DHSJordASFRs2007.dta"
append using "Data/Eat/DHSJordASFRs2002.dta"

drop if age == .
ren rates1 asfr
gen round = ceil(date)

tostring age, replace
encode age, gen(agegrp5)

drop age date

save "Data/Eat/DHSJordASFRs_Bongaarts.dta", replace

** Prop ever married by age group
use "Data/DHS_with_characteristics all.dta", clear

keep sample_wt evermarried agegrp5 round

collapse evermarried [aw=sample_wt], by(round agegrp5)
save "Data/Eat/DHSJordMarr_Bongaarts.dta", replace

*Merging
merge 1:m round agegrp5 using "Data/Eat/DHSJordASFRs_Bongaarts.dta"
drop _merge

*Calculating index
/* C_m(a)= TFR/TM = sum(f_m(a))/sum(f_m(a)/m(a)) */

gen f_a = asfr
*drop g_a
gen g_a = f_a/evermarried

/* g(15-19) = 0.75 x g(20-24) estimate tends to be used */
sort round agegrp5
foreach x of varlist g_a {
	replace `x' = `x'[_n+1]*0.75 if agegrp5 == 1
}

collapse (sum) f_a g_a, by(round)

gen tfr = (f_a*5) /* TFR = (sum(asfr)*5)/1000 */
gen tm = (g_a*5) /* TM = (sum(g_a)*5)/1000 */

gen marr_index = tfr/tm

*Saving
keep round marr_index
save "Data/Eat/DHSJord_Bongaarts_Indices.dta", replace

******************
* Contraception index
*******************
*Stover sources for effectiveness

*Married women
use "Data/DHS_with_characteristics all contra.dta", clear

fre current_method
/* amenorrhea with none to not double count */
/* injections and implants with sterilization */
recode current_method (0 13 = 0 none) ///
(1 = 1 pill) (2 = 2 iud) (3 6 7 11 = 3 sterilization) ///
					(4 5 8 9 10 12 13 14 15 17 = 4 other)  ///
					, gen(method_cat) label(cat5)

*Stats on EC

tabu v307_16 round, miss
tabu v304_16 round [aw=sample_wt], miss	col nofreq				
					
					
*tab method_cat round						
tab method_cat, gen(dum)

collapse dum* [aw=sample_wt], by(round)

ren dum1 none
ren dum2 pill
ren dum3 iud
ren dum4 sterilization
ren dum5 other

*Proportion using contraceptioin
gen u = pill + iud + sterilization + other 

*Estimated effectiveness of methods (u*e Bongaarts 1982, developing countries)
gen e = (1.0*sterilization + 0.95*iud + 0.90*pill + 0.7*other)/u

*Calculating contraception index
gen contra_index = 1 - 1.08*u*e /* C_c(a)= 1 - 1.08*u*e */

*Saving
keep round contra_index u /* need u for abortion index */
merge 1:1 round using "Data/Eat/DHSJord_Bongaarts_Indices.dta"
drop _merge
save "Data/Eat/DHSJord_Bongaarts_Indices.dta", replace

******************
* Abortion index
*******************

*Getting TFR for each round
use "Data/Eat/DHSJordASFRs201718.dta", clear
append using "Data/Eat/DHSJordASFRs2012.dta"
append using "Data/Eat/DHSJordASFRs2009.dta"
append using "Data/Eat/DHSJordASFRs2007.dta"
append using "Data/Eat/DHSJordASFRs2002.dta"

gen round = ceil(date)
keep if age == .
ren rates1 tfr
drop date age

save "Data/Eat/DHSJordTFRs_all.dta", replace


/* total abortion rate -- average number of abortions over lifetime, assuming current age-specific abortion rates continue*/

*****2017

*Woman file - ever married
use "DHSs/Jordan 2017-2018/JOIR73DT/JOIR73FL.dta", clear

*Jordanians only
keep if s123a == 1

*Had recent abortion from terminated pregnancy (2013-2017)
tab s234a, mi
gen recent_abortion = (s234a == 2 & v230>=2013 & v230<=2017)

*Annual probability of abortion
gen rate_abortions_peryr = recent_abortion/5

*Collapse age-specific
*5 year age groups
codebook v013
tab v013
gen agegrp5 = v013 
recode agegrp5 (15/19 = 1) (20/24 = 2) (25/29 = 3) (30/34 = 4) ///
(35/39 = 5) (40/44 = 6) (45/49 = 7)

label def Lagegrp5 1 "15-19" 2 "20-24" 3 "25-29" 4 "30-34" 5 "35-39" ///
6 "40-44" 7 "45-49"
label values agegrp5 Lagegrp5

collapse rate_abortions_peryr [aw=v005], by(agegrp5)

*Sum across years *5 to get total abortion rate
collapse (sum) rate_abortions_peryr 

gen tar=rate_abortions_peryr*5

drop rate_

gen round = 2017

save "Data/Eat/DHSJordAbort2017.dta", replace


****2012

*Woman file - ever married
use "DHSs/Jordan 2012/JOIR6ADT/JOIR6AFL.dta", clear

gen round=2012

rename v003 pn

merge 1:1 round v001 v002 pn using "Data/Eat/DHS nationality var.dta", keepusing(sh07) update

drop if _merge==2

*Jordanians only
keep if sh07 == 1

*Had recent abortion from terminated pregnancy (2007-2011)
tab s230a, mi
gen recent_abortion = (s230a == 2 & v230>=2007 & v230<=2011)

*Annual probability of abortion
gen rate_abortions_peryr = recent_abortion/5

*Collapse age-specific
*5 year age groups
codebook v013
tab v013
gen agegrp5 = v013 
recode agegrp5 (15/19 = 1) (20/24 = 2) (25/29 = 3) (30/34 = 4) ///
(35/39 = 5) (40/44 = 6) (45/49 = 7)

label def Lagegrp5 1 "15-19" 2 "20-24" 3 "25-29" 4 "30-34" 5 "35-39" ///
6 "40-44" 7 "45-49"
label values agegrp5 Lagegrp5

collapse rate_abortions_peryr [aw=v005], by(agegrp5)

*Sum across years *5 to get total abortion rate
collapse (sum) rate_abortions_peryr 

gen tar=rate_abortions_peryr*5

drop rate_

gen round = 2012

save "Data/Eat/DHSJordAbort2012.dta", replace




****2009

*Woman file - ever married
use "DHSs/Jordan 2009/JOIR61DT/JOIR61FL.dta", clear

gen round=2009

rename v003 pn

merge 1:1 round v001 v002 pn using "Data/Eat/DHS nationality var.dta", keepusing(sh07) update

drop if _merge==2

*Jordanians only
keep if sh07 == 1

*Had recent abortion from terminated pregnancy (2004-2008)
tab s229a, mi
gen recent_abortion = (s229a == 2 & v230>=2004 & v230<=2008)

*Annual probability of abortion
gen rate_abortions_peryr = recent_abortion/5

*Collapse age-specific
*5 year age groups
codebook v013
tab v013
gen agegrp5 = v013 
recode agegrp5 (15/19 = 1) (20/24 = 2) (25/29 = 3) (30/34 = 4) ///
(35/39 = 5) (40/44 = 6) (45/49 = 7)

label def Lagegrp5 1 "15-19" 2 "20-24" 3 "25-29" 4 "30-34" 5 "35-39" ///
6 "40-44" 7 "45-49"
label values agegrp5 Lagegrp5

collapse rate_abortions_peryr [aw=v005], by(agegrp5)

*Sum across years *5 to get total abortion rate
collapse (sum) rate_abortions_peryr 

gen tar=rate_abortions_peryr*5

drop rate_

gen round = 2009

save "Data/Eat/DHSJordAbort2009.dta", replace




****2007

*Woman file - ever married
use "DHSs/Jordan 2007/JOIR51DT/JOIR51FL.dta", clear

gen round=2007

rename v003 pn

merge 1:1 round v001 v002 pn using "Data/Eat/DHS nationality var.dta", keepusing(sh07) update

drop if _merge==2

*Jordanians only
keep if sh07 == 1

*Had recent abortion from terminated pregnancy (2002-2006)
tab s229a, mi
gen recent_abortion = (s229a == 2 & v230>=2002 & v230<=2006)

*Annual probability of abortion
gen rate_abortions_peryr = recent_abortion/5

*Collapse age-specific
*5 year age groups
codebook v013
tab v013
gen agegrp5 = v013 
recode agegrp5 (15/19 = 1) (20/24 = 2) (25/29 = 3) (30/34 = 4) ///
(35/39 = 5) (40/44 = 6) (45/49 = 7)

label def Lagegrp5 1 "15-19" 2 "20-24" 3 "25-29" 4 "30-34" 5 "35-39" ///
6 "40-44" 7 "45-49"
label values agegrp5 Lagegrp5

collapse rate_abortions_peryr [aw=v005], by(agegrp5)

*Sum across years *5 to get total abortion rate
collapse (sum) rate_abortions_peryr 

gen tar=rate_abortions_peryr*5

drop rate_

gen round = 2007

save "Data/Eat/DHSJordAbort2007.dta", replace





****2002

*Woman file - ever married
use "DHSs/Jordan 2002/JOIR42DT/JOIR42FL.dta", clear

gen round=2002

*Jordanians only not possible

*Had recent abortion from terminated pregnancy (1997-2001)
tab s229a, mi
gen recent_abortion = (s229a == 2 & v230>=1997 & v230<=2001)

*Annual probability of abortion
gen rate_abortions_peryr = recent_abortion/5

*Collapse age-specific
*5 year age groups
codebook v013
tab v013
gen agegrp5 = v013 
recode agegrp5 (15/19 = 1) (20/24 = 2) (25/29 = 3) (30/34 = 4) ///
(35/39 = 5) (40/44 = 6) (45/49 = 7)

label def Lagegrp5 1 "15-19" 2 "20-24" 3 "25-29" 4 "30-34" 5 "35-39" ///
6 "40-44" 7 "45-49"
label values agegrp5 Lagegrp5

collapse rate_abortions_peryr [aw=v005], by(agegrp5)

*Sum across years *5 to get total abortion rate
collapse (sum) rate_abortions_peryr 

gen tar=rate_abortions_peryr*5

drop rate_

gen round = 2002

save "Data/Eat/DHSJordAbort2002.dta", replace

append using "Data/Eat/DHSJordAbort2007.dta"
append using "Data/Eat/DHSJordAbort2009.dta"
append using "Data/Eat/DHSJordAbort2012.dta"
append using "Data/Eat/DHSJordAbort2017.dta"

** Calculating induced abortion index 
*Merging 
merge 1:1 round using "Data/Eat/DHSJord_Bongaarts_Indices.dta"
drop _merge
merge 1:1 round using "Data/Eat/DHSJordTFRs_all.dta"
drop _merge

gen abortion_index = tfr / (tfr + 0.4*(1+u)*tar) /* C_a=TFR/(TFR+b*TAR), b = 0.4(1+u) */
drop u tar

save "Data/Eat/DHSJord_Bongaarts_Indices.dta", replace

******************
* Postpartum infecundability index
*******************

use "Data/DHS_with_characteristics all contra.dta", clear

*Stat: sex

gen sex_4wk=1 if v536==1
replace sex_4wk=0 if v536==3 | v536==4

table round agegrp5 [aw=sample_wt], c(mean sex_4wk) row col
table round v201 [aw=sample_wt], c(mean sex_4wk) row col


*Stat: declared infecund

gen infec=1 if v605==7
replace infec=0 if v605!=7 & v605!=. 

table round agegrp5 [aw=sample_wt], c(mean infec) row col

table round v201 [aw=sample_wt], c(mean infec) row col


/*Estimate mean duration in months of lactation with proportion of women currently lactating by duration since last birth
*/

collapse v404 [aw=sample_wt], by(round v222)

collapse (sum) v404, by(round)


*Calculating infecundability index
/* C_i(a)=20/(18.5+i(a)) i = 1.753 exp(0.1396*B -0.001872*B*B)*/
gen i=(1.753*exp(0.1396*v404-0.001872*v404*v404))
gen infecund_index1 = 20 /(18.5 + i) 


keep round infecund_index*
merge 1:1 round using "Data/Eat/DHSJord_Bongaarts_Indices.dta"
drop _merge

save "Data/Eat/DHSJord_Bongaarts_Indices.dta", replace

******************
* Aggregate model
*******************
use "Data/Eat/DHSJord_Bongaarts_Indices.dta", clear

*TFR approximation (TF = 15.3)
gen tfr_approx = infecund_index*contra_index*marr_index*abortion_index*15.3 
/* TFR = C_m*C_c*C_i*C_a*TF */

gen residual=tfr/tfr_approx

order round marr_index contra_index infecund_index abortion_index tfr_approx tfr residual

export excel "Graphs and Tables/Bongaarts decomp.xlsx", first(var) replace


