***Jordan DHS Contraception Descriptive Statistics
*Trends in contraceptive use 
*v26
*Libby Kula, Caroline Krafft
*Original: 3/17/2020
*Update: 2021.04.15

clear
set scheme s1mono

use "Data/DHS_with_characteristics all.dta", clear

*Currently married women only
keep if marital_status==1

*Currently pregnant
codebook v213
tab v213
ren v213 currently_pregnant


***Contraception***

*Ever use 
codebook v302a /* 2012-2017/18 */
tab round v302a, mi

codebook v302 /* 2002-2009 */
tab round v302, mi

gen ever_use=v302
replace ever_use = v302a if (round == 2012 | round == 2017 | round == 2018)
tab ever_use
recode ever_use (1=0) (2/3=1)
tab ever_use, mi

*Current use indicators 
codebook v312
tab v312
ren v312 current_method

codebook v313
tab v313
ren v313 modern_trad

*Any method
recode modern_trad (2 3 =1), gen(any_method)
label define modern2 0 "No method" 1 "Any method"
label values any_method modern2
tab modern_trad any_method

*Modern method 
gen modern = modern_trad == 3
label define modern1 0 "No modern method" 1 "Modern method"
label values modern modern1
tab modern_trad modern

gen trad = modern_trad == 2
tab modern_trad trad 

**LARC
rename v307_02 current_use_IUD
rename v307_03 current_use_Injection
rename v307_11 current_use_norplant

gen LARC = 0 if modern!=.
replace LARC=1 if current_use_IUD==1 | current_use_Injection==1  |  current_use_norplant==1

tab LARC [aw=sample_wt], mi

save "Data/DHS_with_characteristics all contra.dta", replace


/**************************************/
/* Contraception - Graphs and Tables  */
/**************************************/

/* Descriptive Tables */

**Jordanians
tab round [aw=sample_wt], summ(ever_use)
tab round [aw=sample_wt], summ(any_method)
tab round [aw=sample_wt], summ(modern)
tab round [aw=sample_wt], summ(trad)
tab round [aw=sample_wt], summ(LARC)

*Time series with ever, current, mod, trad, and LARC

preserve
collapse ever_use any_method modern trad LARC [aw=sample_wt] , by(round)


foreach var of varlist ever_use any_method modern trad LARC {
replace `var'=round(`var'*100)
}

graph twoway scatter ever_use round, ///
 lpattern("l") plotregion(margin(b=0)) connect("l") mlabel(ever_use)  ///
 mlabposition(12) color(gs6) || ///
 scatter any_method round, ///
 lpattern("l") plotregion(margin(b=0)) connect("l") mlabel(any_method)  ///
 mlabposition(12) color(gs10) || ///
 scatter modern round, ///
 lpattern("l") plotregion(margin(b=0)) connect("l") mlabel(modern)  ///
 mlabposition(12) color(gs8) || ///
 scatter trad round, ///
 lpattern("l") plotregion(margin(b=0)) connect("l") mlabel(trad)  ///
 mlabposition(12) color(gs3) || ///
 scatter LARC round, ///
 lpattern("l") plotregion(margin(b=0)) connect("l") mlabel(LARC)  ///
 mlabposition(12) color(gs1) || ///
 , xtitle(" " "Year") ytitle(" " "Percent of currently married women") ///
 legend(label(1 "Ever Used") label(2 "Currently Using") label(3 "Modern (currently)") /// 
 label(4 "Traditional (currently)") label(5 "LARC (currently)")) ///
 ylabel(0(20)100) ylabel(0(20)100) ///
 xlabel(2002 2007 2009 2012 2017, labsize(small)) xtick(2002 2007 2009 2012 2017) 
 

/* Figure 7. Contraceptive use by method type over time (percentages) */
graph save "Graphs and Tables/contra_time_series.gph", replace
graph export "Graphs and Tables/contra_time_series.png", replace

restore

preserve
*Modern graph
collapse modern [aw=sample_wt] , by(round agegrp5 educ_3cat)

replace modern=modern*100

*Drop higher ed 15-19
drop if agegrp5 == 1 & educ_3cat == 3

graph twoway connect modern agegrp5 if round==2009, ///
  color(gs13) msymbol(D) by(educ_3cat, note("")) lpattern("l") ///
  plotregion(margin(b=0)) || ///
 connect modern agegrp5 if round==2012, ///
  color(gs10) msymbol(S) by(educ_3cat, note("")) lpattern("l") ///
  plotregion(margin(b=0))  || ///
 connect modern agegrp5 if round==2017, ///
  color(gs7) msymbol(T) by(educ_3cat, note("")) lpattern("l") ///
  plotregion(margin(b=0))  || ///
 , xtitle("Age Group") ytitle("Percent using modern contraception") ///
 xtick(1/7) xla(1/7, val) ///
 legend(label(1 "JPFHS 2009") label(2 "JPFHS 2012") label(3 "JPFHS 2017/18"))

/* Figure 8. Modern contraception use by age and education */ 
graph save "Graphs and Tables/dhs_modern_age_ed.gph", replace
graph export "Graphs and Tables/dhs_modern_age_ed.png", replace

restore

preserve
/*By parity among currently married*/
recode tot_ch(3/20=3)
la def Lpar 3 "3+"

table tot_ch round [aw=sample_wt], c(mean any_method)
table tot_ch round [aw=sample_wt], c(mean modern)
table tot_ch round [aw=sample_wt], c(mean LARC)

label define pars 0 "Married without children" 1 "One child" 2 "Two children" 3 "Three or more children"
lab values tot_child pars

collapse modern [aw=sample_wt] , by(round tot_child)

replace modern=round(modern*100)

graph  ///
 twoway scatter modern round if tot_child==0, ///
 lpattern("l") plotregion(margin(b=0)) connect("l") mlabel(modern)  ///
 mlabposition(12) color(gs13) || ///
 scatter modern round if tot_child==1, ///
  lpattern("l") plotregion(margin(b=0)) connect("l") mlabel(modern)  ///
 mlabposition(12) color(gs10) || ///
 scatter modern round if tot_child==2, ///
  lpattern("l") plotregion(margin(b=0)) connect("l") mlabel(modern)  ///
 mlabposition(12) color(gs7) || ///
 scatter modern round if tot_child==3, ///
  lpattern("l") plotregion(margin(b=0)) connect("l") mlabel(modern)  ///
 mlabposition(12) color(gs4) || ///
 , xtitle(" " "Year") ytitle("Percent using modern contraception") ///
 legend(label(1 "Married without children") label(2 "One child") label(3 "Two children") /// 
 label(4 "Three or more children")) ///
 ylabel(0(10)60) ylabel(0(10)60) ///
 xlabel(2002 2007 2009 2012 2017, labsize(small)) xtick(2002 2007 2009 2012 2017) 
 

/* Figure 9. Modern contraception use by parity over time */
graph save "Graphs and Tables/parity_mod_contra_time.gph", replace
graph export "Graphs and Tables/parity_mod_contra_time.png", replace

restore

*****************
/*Pregnancy*/
*****************
use "Data/DHS_with_characteristics all contra.dta", clear
*Among currently married

*Currently amenorrheic
ren v405 currently_amenorrheic

table agegrp5 round [pw=sample_wt], c(mean currently_pregnant)
table agegrp5 round [pw=sample_wt], c(mean currently_amenorrheic)

*Pregnancy & amenorrhea by age group

gen perc_preg=currently_pregnant*100
format perc_preg %4.0f

gen perc_amenorr=currently_amenorrheic*100
format perc_amenorr %4.0f

gen perc_either = perc_preg + perc_amenorr
format perc_either %4.0f

drop if round <2009
tab agegrp5 round, mi

/* Table 6.  Percent of currently married Jordanian women pregnant or post-partum
amenorrhoeic by age group */
tabout agegrp5 round using "Graphs and Tables/table6_preg.csv" [aw=sample_wt], ///
 replace style(csv) c(mean perc_preg) f(0 0) clab(%) sum h1(nil) ///
 h2(Age group | JPFHS 2009 | JPFHS 2012 | JPFHS 2017/18) h3(nil) ptotal(single)

tabout agegrp5 round using "Graphs and Tables/table6_amenorr.csv" [aw=sample_wt], ///
 replace style(csv) c(mean perc_amenorr) f(0) clab(%) sum ///
 h1(nil) h2(Age group | JPFHS 2009_a | JPFHS 2012_a | ///
 JPFHS 2017/18_a) h3(nil) ptotal(single)

tabout agegrp5 round using "Graphs and Tables/table6_either.csv" [aw=sample_wt], ///
 replace style(csv) c(mean perc_either) f(0) clab(%) sum ///
 h1(nil)  h2(Age group | JPFHS 2009_b | JPFHS 2012_b | ///
 JPFHS 2017/18_b) h3(nil) ptotal(single)
 
import delimited "Graphs and Tables/table6_preg.csv", clear 
save "Data/Eat/table6_preg.dta", replace

import delimited "Graphs and Tables/table6_amenorr.csv", clear 
save "Data/Eat/table6_amenorr.dta", replace

import delimited "Graphs and Tables/table6_either.csv", clear 
save "Data/Eat/table6_either.dta", replace

use "Data/Eat/table6_preg.dta", clear
merge 1:1 agegroup using "Data/Eat/table6_amenorr.dta", gen(amen)
merge 1:1 agegroup using "Data/Eat/table6_either.dta", gen(either)
drop v5 amen either
drop if agegroup == "agegrp5"
