***Jordan DHS Contraception Model
*Trends in contraceptive use 
*v5
*Libby Kula, Caroline Krafft
*Original: 7/15/2020
*Update: 7/31/2020

set matsize 800

estimates clear

set scheme s1mono

*Data with contraceptives measures
use "Data/DHS_with_characteristics all contra.dta", clear

recode tot_child (4/19=4) 
la def Ltot_child 0 "Married" 4 "4+"

*Probit model for over time
probit modern b2009.round [pw=sample_wt]
estimates store cest1

*Probit model for over time with controls for age, education
probit modern b2009.round b3.agegrp5 i.educ_3cat [pw=sample_wt]
estimates store cest2

*Probit model for over time with interactions for age, education
probit modern b2009.round b3.agegrp5 i.educ_3cat ///
b2009.round#b3.agegrp5 b2009.round#i.educ_3cat [pw=sample_wt]
estimates store cest3

*Probit model for over time with controls for age, education, AND PARITY
probit modern b2009.round b3.agegrp5 i.educ_3cat i.tot_child  [pw=sample_wt]
estimates store cest4

*Probit model for over time with interactions for parity
probit modern  b2009.round b3.agegrp5 i.educ_3cat b2009.round##i.tot_child [pw=sample_wt]
estimates store cest5

la def C_round 2002 "2002" 2007 "2007" 2009 "2009" 2012 "2012" 2017 "2017/18"
la val round C_round

la def C_tot_child 1 "1st" 2 "2nd" 3 "3rd" 4 "4th+"
la val tot_child C_tot_child

/* Table A-4. Contraception probit models */
esttab cest1 cest2 cest3 cest4 cest5 ///
 using "Graphs and Tables/ContraModels.csv", ///
 cells(b(star fmt(%9.3f)) se(par)) ///     
 stats(N, fmt(%9.0g %9.0g) labels("N obs.")) label  ///
 nobase noomit ///
 refcat( 2002.round "Round (2009 omit.)" 1.agegrp5 "Age group (25-29 omit.)"  ///
 2.educ_3cat "Ed. (less than sec. omit.)" ///
 2002.round#1.agegrp5 "Round and age group int." ///
 2002.round#2.educ_3cat "Round and ed. int." ///
 1.tot_child "Parity (Marr. omit.)" ///
 2002.round#1.tot_child "Round and parity int." ///
 , nolabel) ///
 replace
