***Jordan DHS 2017 Fertility data creation (for multivariate models)
*v5(following JPFHS dataprep 6Dec19.do/BA Fert data creation v5) 
***Data preparation file
***Original: 3/13/2020
***Updated: 2020.07.18

use "Data/DHS_with_characteristics 2017.dta", clear

*Check
tabu v007

*N=24,251

*Keep married
keep if nevmar==0

*Check
d, short

********************************************
*** Sociodemographic characteristics
********************************************

***Time invariant
*Governorate
rename v024 gov
fre gov

*Sample weight
sum sample_wt
*was v005

*Education
fre educ_3cat

*age
fre age
rename age age

*Residence
fre urban_rural

*Nationality
fre nationality

*Birth year and month
fre brthyr
fre brthmth

*CMC birthdate
rename v011 cmcbrthyr

*Birth years for each child
sum yrbirth_*
drop yrbirth_17 yrbirth_18 yrbirth_19 yrbirth_20 /*No one has more than 16 kids*/
	
*Birth months for each child
sum mnthbirth_*
drop mnthbirth_17 mnthbirth_18 mnthbirth_19 mnthbirth_20 /*No one has more than 16 kids*/

*Sex of each child
rename b4_* sxchild_*
rename sxchild_0* sxchild_*
drop sxchild_17 sxchild_18 sxchild_19 sxchild_20

*Total children
fre tot_child

*Year
rename v007 year

*age at first marriage
fre age1stmarr

*Year of 1st marriage
fre yr1stmarr

*Keep only what I need before I reshape 
keep age year indid yrbirth_* mnthbirth_* sxchild_* brthyr brthmth yr1stmarr ///
educ_3cat nationality urban_rural ///
sample_wt ///
cmcbrthyr tot_child gov

gen yrbirth_0 =yr1stmarr

*Finding those married and first birth in same year
count if yrbirth_0 == yrbirth_1
*85

reshape long yrbirth_@ mnthbirth_@ sxchild_@, i(indid) j(bord)

*browse indid bord yrbirth_ mnthbirth_ sxchild_ 
drop if yrbirth_ == .

*Reversing the ordering of the yrbirth_ variable

gen new_bord = 0
bysort indid bord : replace new_bord = 1 if bord != 0 & bord == tot_child
bysort indid bord : replace new_bord = 2 if bord != 0 & bord == tot_child - 1
bysort indid bord : replace new_bord = 3 if bord != 0 & bord == tot_child - 2
bysort indid bord : replace new_bord = 4 if bord != 0 & bord == tot_child - 3
bysort indid bord : replace new_bord = 5 if bord != 0 & bord == tot_child - 4
bysort indid bord : replace new_bord = 6 if bord != 0 & bord == tot_child - 5
bysort indid bord : replace new_bord = 7 if bord != 0 & bord == tot_child - 6
bysort indid bord : replace new_bord = 8 if bord != 0 & bord == tot_child - 7
bysort indid bord : replace new_bord = 9 if bord != 0 & bord == tot_child - 8
bysort indid bord : replace new_bord = 10 if bord != 0 & bord == tot_child - 9
bysort indid bord : replace new_bord = 11 if bord != 0 & bord == tot_child - 10
bysort indid bord : replace new_bord = 12 if bord != 0 & bord == tot_child - 11
bysort indid bord : replace new_bord = 13 if bord != 0 & bord == tot_child - 12
bysort indid bord : replace new_bord = 14 if bord != 0 & bord == tot_child - 13
bysort indid bord : replace new_bord = 15 if bord != 0 & bord == tot_child - 14
bysort indid bord : replace new_bord = 16 if bord != 0 & bord == tot_child - 15

drop bord
ren new_bord bord
la var bord "Birth number" 
la val bord
fre bord

sort indid bord


*Have a male child already
gen ch_male=0 if sxchild_==2
replace ch_male=1 if sxchild_==1

gen n_male=0 
bysort indid: replace n_male=sum(ch_male)
 
*Have male
gen have_male=(n_male!=0)

*Dropping multiple in same year 
duplicates report indid yrbirth_
duplicates drop indid yrbirth_, force

sort indid yrbirth_ bord


*Year interval as a survival model
gen interval=.
replace interval=yrbirth_[_n+1]-yrbirth_[_n] if indid[_n]==indid[_n+1]

gen has_next=0
replace has_next=1 if interval!=.
replace interval=(year - yrbirth_) if interval==.
sum interval

table yrbirth_ if has_next==1 [aw=sample_wt], c(mean interval)

expand interval
*zero counts ignored, these are folks who just gave birth 

bysort bord indid: gen int_length=_n
sort indid bord int_length
tabu int_length

*Failure
gen next_born=0
bysort indid bord: replace next_born=1 if has_next==1 & int_length==_N

*Generate a variable for the calendar year
bysort indid bord: gen interval_year=floor((yrbirth_+_n))
tabu interval_year

*Generating age in year
gen age_inyr=interval_year-brthyr+1
tabu age_inyr

*age groups for age in year
gen yr_agroup=.
replace yr_agroup=1 if age_inyr>=0 & age_inyr<=19
replace yr_agroup=2 if age_inyr>=20 & age_inyr<=24
replace yr_agroup=3 if age_inyr>=25 & age_inyr<=29
replace yr_agroup=4 if age_inyr>=30 & age_inyr<=34
replace yr_agroup=5 if age_inyr>=35 & age_inyr<=39
replace yr_agroup=6 if age_inyr>=40 & age_inyr<=44
replace yr_agroup=7 if age_inyr>=45 & age_inyr<=50

la def Lyr_agroup 1 "<20" 2 "20-24" 3 "25-29" 4 "30-34" 5 "35-39" ///
6 "40-44" 7 "45-49"

la val yr_agroup Lyr_agroup

tabu yr_agroup, miss

*Year (time varying)
drop year
gen year=interval_year
replace year=. if year>2017

*age in year
keep if age_inyr>=15 & age_inyr<=49

*We can recode year into cohorts
keep if year>=2000 & year<=2016

recode year (2000/2004=1) ///
(2005/2009=2) (2010/2016=3) (.=.) (9998=.), gen(tyr)

label var tyr "Years"
label define tyrlab 1 "2000-2004" 2 "2005-2009" 3 "2010-2016", modify
label values tyr tyrlab

tabu tyr, miss


*Birth id
label val bord 
tabu bord

tostring bord, gen(s_bord)
replace s_bord="0"+s_bord if bord<10

gen bid=indid+s_bord
*duplicates report bid int_length

*Aggregating higher intervals

tabu int_length next_born [aw=sample_wt], row
tabu int_length next_born, row

tabu bord [aw=sample_wt] if int_length==1

gen c_bord=bord
replace c_bord=4 if c_bord>4 & c_bord<.

gen c_int_length=int_length
replace c_int_length=6 if c_int_length>6 & c_int_length<.

label var c_bord "Parity"
label var c_int_length "Years since last event"

*Keep for modeling
keep indid sample_wt gov urban_rural educ_3cat c_bord ///
c_int_length next_born have_male year yr_agroup

save "Data/DHS 2017 annual fert.dta", replace
