***DHS Data Prep 
*Descriptives
*v8
*Libby Kula, Caroline Krafft
*Original: 2020.07.01
*Updated: 2021.02.03

*Getting nationality variable (only in 2007 onward)
use "DHSs/Jordan 2012/JOPR6ADT/JOPR6AFL.DTA", clear
gen round=2012
append using "DHSs/Jordan 2009/JOPR61DT/JOPR61FL.dta"
replace round=2009 if round==.
append using "DHSs/Jordan 2007/JOPR51DT/JOPR51FL.dta"
replace round=2007 if round==.
keep sh07 hv001 hv002 hvidx round
rename hv* v*

rename vidx pn

tabu round

save "Data/Eat/DHS nationality var.dta", replace

*Combine waves, married (responded) and unmarried
use "Data/Eat/DHS Jord 2017-18 rawsplit.dta", clear
gen round=2017
append using "Data/Eat/DHS Jord 2012 rawsplit.dta"
replace round=2012 if round==. 
append using "Data/Eat/DHS Jord 2009 rawsplit.dta"
replace round=2009 if round==.
append using "Data/Eat/DHS Jord 2007 rawsplit.dta"
replace round=2007 if round==. 
append using "Data/Eat/DHS Jord 2002 rawsplit.dta"
replace round=2002 if round==. 
append using "Data/Eat/DHS never-married.dta", gen(nevmar)

*Line number
gen pn=vidx
replace pn=v003 if caseid!=""

drop caseid

*Individual identifier
gen indid=string(round, "%04.0f")+string(v001, "%03.0f")+string(v002,"%02.0f")+string(pn, "%02.0f")


isid round v001 v002 pn
isid indid

*Merge in nationality
merge 1:1 round v001 v002 pn using "Data/Eat/DHS nationality var.dta", keepusing(sh07) update
tabu round _merge
drop if _merge==2

*Sample weight
ren v005 sample_wt

*Residence
codebook v025
ren v025 urban_rural
tab urban_rural, mi

*Nationality
gen nationality = .
replace nationality=1 if s123a==1 | sh07==1
replace nationality=2 if s123a==3 | sh07==3
replace nationality=3 if s123a==2 | sh07==2
replace nationality=3 if s123a>=4 & s123a<=8
replace nationality=3 if sh07>=4 & sh07<=6

label define nat 1 "Jordanian" 2 "Syrian" 3 "Other"
label values nationality nat
tabu round nationality, miss

*save 

*Education - years of schooling
*Years of school
gen yrschl=v108 if nevmar == 1
replace yrschl=v133 if nevmar == 0
replace yrschl=. if yrschl==99
fre yrschl

gen educ_3cat = yrschl
recode educ_3cat (98 99 = .) (0/11 = 1) (12 13 = 2) (14/max = 3)
label define Educ_3 1 "Less than secondary" 2 "Secondary" 3 "Higher education"
label values educ_3cat Educ_3
tab educ_3cat, mi

*age
gen age = v012 if nevmar == 0
replace age = v105 if nevmar == 1
tab age, mi

*5 year age groups
codebook v013
tab v013
gen agegrp5 = v013 if nevmar == 0
replace agegrp5 = age if nevmar ==1 
recode agegrp5 (15/19 = 1) (20/24 = 2) (25/29 = 3) (30/34 = 4) ///
(35/39 = 5) (40/44 = 6) (45/49 = 7)

label def Lagegrp5 1 "15-19" 2 "20-24" 3 "25-29" 4 "30-34" 5 "35-39" ///
6 "40-44" 7 "45-49"
label values agegrp5 Lagegrp5

***Dates

*CMC interview date
ren v008 cmcintdate 

*Birthdate
gen brthyr = v010 if nevmar == 0
gen brthmth = v009 if nevmar == 0

replace brthyr = sh06ay if nevmar == 1 & round==2017
replace brthmth = sh06am if nevmar == 1 & round==2017

replace brthyr = sh06y if nevmar == 1 & round!=2017
replace brthmth = sh06m if nevmar == 1 & round!=2017

replace brthyr = . if brthyr == 9998
replace brthmth = . if brthmth == 98

tabu brthyr round, miss
tabu brthmth round, miss


*CMC birthdate
gen cmcbrthdate = v011 if nevmar == 0
replace cmcbrthdate = 12*(brthyr - 1900) + brthmth if nevmar == 1
bysort round: sum cmcbrthdate
tabu round if cmcbrthdate==.


*Birth years for each child
rename b2_* yrbirth_*
rename yrbirth_0* yrbirth_*
	
*Birth months for each child
rename b1_* mnthbirth_*
rename mnthbirth_0* mnthbirth_*

*CMC date of births
foreach num of numlist 1/20 {
	
	gen cmcyrbirth_`num'=(yrbirth_`num'-1900)*12+mnthbirth_`num'
	tabu cmcyrbirth_`num'
}

*age at first marriage
ren v511 age1stmarr
label var age1stmarr "age at first marriage" 
tabu age1stmarr nev, miss

*Year of first marriage
ren v508 yr1stmarr
label var yr1stmarr "Year of first marriage"
tabu yr1stmarr nev, miss

*Marriage to first birth interval
gen marr_b_int = v221
replace marr_b_int = . if nevmar == 1
replace marr_b_int = . if marr_b_int == 996
bysort round: sum marr_b_int

*Marital status
replace marital_status=v501 if nevmar == 0
recode marital_status (3/5=2)
label define Marital_rec2 0 "Never married" 1 "Married" 2 "Previously married"
label value marital_status Marital_rec2
tab marital_status v501, mi

*Total children ever born
gen tot_child = v201 if nevmar == 0
replace tot_child = 0 if nevmar ==1
tabu tot_child, miss

*Slight cleaning of birth year to align with age for expansion
tabu brthyr, miss
replace brthyr=v007-age if brthyr==.
replace brthyr=v007-age if brthyr+age>v007 & brthyr!=. & age!=.

*Ever married
gen evermarried=0 if marital_status==0
replace evermarried=1 if marital_status>=1
tabu evermarried marital_status, miss

*Generate age at marriage, current age if not married
gen agemarr=.
replace agemarr=age if evermarried==0
replace agemarr=age1stmarr if evermarried==1
*Slight cleaning (N=0)
replace agemarr=age if agemarr>age & agemarr!=. & age!=.

tabu agemarr evermarried, miss

*age at first birth
gen yr1stbrth = .
foreach n of numlist 1/20 {
	replace yr1stbrth = yrbirth_`n' if tot_child == `n'
}

gen ageb1=yr1stbrth-brthyr
tabu ageb1 
replace ageb1 = . if ageb1<0 | ageb1>45

tabu yr1stbrth round, miss

tabu ageb1 round, miss

/* All women factors*/

*Nationality awf
gen allwom = 1

sort age nationality round
by age nationality round: egen tot_jord = total(allwom)
by age nationality round: egen marr_jord = total(nevmar == 0)

gen awfactn = (tot_jord/marr_jord)*100
replace awfactn = . if nevmar == 1
label var awfactn "All woman factor - Nationality" 

tab age, summ(awfactn)

*Education (3 cat) awf
sort age nationality round educ_3cat
by age nationality round educ_3cat: egen tot_jord_ed = total(allwom)
by age nationality round educ_3cat: egen marr_jord_ed = total(nevmar == 0)

gen awfactne = (tot_jord_ed/marr_jord_ed)*100
replace awfactne = . if nevmar == 1
label var awfactne "All woman factor - Education & nationality" 
tab age educ_3cat, summ(awfactne)

/*Stat: sample size, JPFHS*/
tab round, mi
tab round evermarried, mi

save "Data/Eat/DHS_with_characteristics all nationalities.dta", replace

*Jordanians only (or 2002 when did not have nationality)
keep if nationality==1 |  round==2002

save "Data/DHS_with_characteristics all.dta", replace

*2017 only
drop if v007 <2017

*Check unique
isid v001 v002 pn
isid indid

save "Data/DHS_with_characteristics 2017.dta", replace

*****************
* Preparing KR file (for Bongaarts postpartum amenhorric duration, etc.)
*****************
*Combine waves
use "DHSs/Jordan 2017-2018/JOKR73DT/JOKR73FL.dta", clear
gen round=2017
append using "DHSs/Jordan 2012/JOKR6ADT/JOKR6AFL.dta"
replace round=2012 if round==. 
append using "DHSs/Jordan 2009/JOKR61DT/JOKR61FL.dta"
replace round=2009 if round==.
append using "DHSs/Jordan 2007/JOKR51DT/JOKR51FL.dta"
replace round=2007 if round==. 
append using "DHSs/Jordan 2002/JOKR42DT/JOKR42FL.dta"
replace round=2002 if round==. 

*Line number
gen pn=midx
replace pn=v003 if caseid!=""

*Merge in nationality
merge m:1 round v001 v002 pn using "Data/Eat/DHS nationality var.dta", keepusing(sh07) update
tabu round _merge
drop if _merge==2

*Sample weight
ren v005 sample_wt

*Nationality
gen nationality = .
replace nationality=1 if s123a==1 | sh07==1
replace nationality=2 if s123a==3 | sh07==3
replace nationality=3 if s123a==2 | sh07==2
replace nationality=3 if s123a>=4 & s123a<=8
replace nationality=3 if sh07>=4 & sh07<=6

label define nat 1 "Jordanian" 2 "Syrian" 3 "Other"
label values nationality nat
tabu round nationality, miss

*Jordanians only (or 2002 when did not have nationality)
keep if nationality==1 |  round==2002

save "Data/DHS_Jord KR all.dta", replace


*****************
* Preparing birth file
*****************
*Combine waves
use "DHSs/Jordan 2017-2018/JOBR73DT/JOBR73FL.dta", clear
gen round=2017
append using "DHSs/Jordan 2012/JOBR6ADT/JOBR6AFL.dta"
replace round=2012 if round==. 
append using "DHSs/Jordan 2009/JOBR61DT/JOBR61FL.dta"
replace round=2009 if round==.
append using "DHSs/Jordan 2007/JOBR51DT/JOBR51FL.dta"
replace round=2007 if round==. 
append using "DHSs/Jordan 2002/JOBR42DT/JOBR42FL.dta"
replace round=2002 if round==. 

*Line number
gen pn=bidx
replace pn=v003 if caseid!=""

*Merge in nationality
merge m:1 round v001 v002 pn using "Data/Eat/DHS nationality var.dta", keepusing(sh07) update
tabu round _merge
drop if _merge==2

*Sample weight
ren v005 sample_wt

*Nationality
gen nationality = .
replace nationality=1 if s123a==1 | sh07==1
replace nationality=2 if s123a==3 | sh07==3
replace nationality=3 if s123a==2 | sh07==2
replace nationality=3 if s123a>=4 & s123a<=8
replace nationality=3 if sh07>=4 & sh07<=6

label define nat 1 "Jordanian" 2 "Syrian" 3 "Other"
label values nationality nat
tabu round nationality, miss

*Jordanians only (or 2002 when did not have nationality)
keep if nationality==1 |  round==2002

save "Data/DHS_Jord births all.dta", replace
